# Musicly

A terminal-based music player for searching and playing songs from the command line.

![Musicly Screenshot](assets/ss.gif)

## Quick Usage 

```bash
uvx musicly 
```

## Installation

```bash
pip install uv
uv pip install musicly
```

## Running

```bash
musicly 
```


## Requirements

- Python >= 3.10 
